@@ -1,3 +1,10 @@
+"""
+$description Japanese live TV streaming website with multiple channels including news, sports, entertainment and anime.
+$url abema.tv
+$type live, vod
+$region Japan
+"""
+
 import hashlib
 import hmac
 import logging
@@ -15,8 +22,7 @@ from requests.adapters import BaseAdapter
 from streamlink.exceptions import NoStreamsError
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import useragents, validate
-from streamlink.stream import HLSStream
-from streamlink.stream.hls import HLSStreamReader, HLSStreamWriter
+from streamlink.stream.hls import HLSStream, HLSStreamReader, HLSStreamWriter
 from streamlink.utils.url import update_qsd
 
 log = logging.getLogger(__name__)
