@@ -1,15 +1,22 @@
+"""
+$description Live TV channels and video on-demand service from the BBC, a British public, state-owned broadcaster.
+$url bbc.co.uk/iplayer
+$type live, vod
+$region United Kingdom
+"""
+
 import base64
 import logging
 import re
 from collections import defaultdict
 from hashlib import sha1
-from urllib.parse import urlparse
+from urllib.parse import urlparse, urlunparse
 
 from streamlink.plugin import Plugin, PluginArgument, PluginArguments, PluginError, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HDSStream, HLSStream
 from streamlink.stream.dash import DASHStream
-from streamlink.utils import parse_json
+from streamlink.stream.hls import HLSStream
+from streamlink.utils.parse import parse_json
 
 log = logging.getLogger(__name__)
 
@@ -46,7 +53,7 @@ class BBCiPlayer(Plugin):
         validate.get("id")
     )
     mediaselector_schema = validate.Schema(
-        validate.transform(parse_json),
+        validate.parse_json(),
         {"media": [
             {"connection":
                 validate.all([{
@@ -82,6 +89,10 @@ class BBCiPlayer(Plugin):
         ),
     )
 
+    def __init__(self, url):
+        super().__init__(url)
+        self.url = urlunparse(urlparse(self.url)._replace(scheme="https"))
+
     @classmethod
     def _hash_vpid(cls, vpid):
         return sha1(cls.hash + str(vpid).encode("utf8")).hexdigest()
@@ -130,8 +141,6 @@ class BBCiPlayer(Plugin):
             log.debug(f"{len(urls)} {stream_type} streams")
             for url in list(urls):
                 try:
-                    if stream_type == "hds":
-                        yield from HDSStream.parse_manifest(self.session, url).items()
                     if stream_type == "hls":
                         yield from HLSStream.parse_variant_playlist(self.session, url).items()
                     if stream_type == "dash":
