@@ -1,9 +1,14 @@
+"""
+$description 24-hour live streaming world news channel, based in the United States of America.
+$url cbsnews.com
+$type live
+"""
+
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
-from streamlink.utils import parse_json
+from streamlink.stream.hls import HLSStream
 
 
 @pluginmatcher(re.compile(
@@ -16,7 +21,7 @@ class CBSNews(Plugin):
         validate.transform(_re_default_payload.search),
         validate.any(None, validate.all(
             validate.get(1),
-            validate.transform(parse_json),
+            validate.parse_json(),
             {"items": [validate.all({
                 "video": validate.url(),
                 "format": "application/x-mpegURL"
