@@ -1,8 +1,14 @@
+"""
+$description Turkish live TV channel owned by Galatasaray TV.
+$url galatasaray.com
+$type live
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
