@@ -1,10 +1,16 @@
+"""
+$description Global live streaming and video on-demand hosting platform.
+$url livestream.com
+$type live
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
-from streamlink.utils import parse_json
+from streamlink.stream.hls import HLSStream
+from streamlink.utils.parse import parse_json
 
 log = logging.getLogger(__name__)
 
