@@ -1,8 +1,14 @@
+"""
+$description Live TV channels from LRT, a Lithuanian public, state-owned broadcaster.
+$url lrt.lt
+$type live
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
