@@ -1,7 +1,13 @@
+"""
+$description Russian live TV channel owned by Gazprom Media.
+$url ntv.ru
+$type live
+"""
+
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 
 @pluginmatcher(re.compile(
