@@ -1,8 +1,14 @@
+"""
+$description Live TV channels and video on-demand service from ORF, an Austrian public, state-owned broadcaster.
+$url tvthek.orf.at
+$type live, vod
+"""
+
 import json
 import re
 
 from streamlink.plugin import Plugin, PluginError, pluginmatcher
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 _json_re = re.compile(r'<div class="jsb_ jsb_VideoPlaylist" data-jsb="(?P<json>[^"]+)">')
 
