@@ -1,9 +1,15 @@
+"""
+$description Global live streaming platform for the creative community.
+$url piczel.tv
+$type live
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
