@@ -1,11 +1,26 @@
+"""
+$description Global and country-specific websites for live radio simulcasts for over 40,000 stations.
+$url radio.net
+$url radio.at
+$url radio.de
+$url radio.dk
+$url radio.es
+$url radio.fr
+$url radio.it
+$url radio.pl
+$url radio.pt
+$url radio.se
+$type live
+"""
+
 import logging
 import re
 from urllib.parse import urlparse, urlunparse
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream, HTTPStream
-from streamlink.utils import parse_json
+from streamlink.stream.hls import HLSStream
+from streamlink.stream.http import HTTPStream
 
 log = logging.getLogger(__name__)
 
@@ -22,7 +37,7 @@ class RadioNet(Plugin):
             None,
             validate.all(
                 validate.get(1),
-                validate.transform(parse_json),
+                validate.parse_json(),
                 {
                     'type': validate.text,
                     'streams': validate.all([{
