@@ -1,11 +1,17 @@
+"""
+$description Live TV channels from RAI, an Italian public, state-owned broadcaster.
+$url raiplay.it
+$type live
+$region Italy
+"""
+
 import logging
 import re
 from urllib.parse import urlparse, urlunparse
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
-from streamlink.utils import parse_json
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
@@ -27,7 +33,7 @@ class RaiPlay(Plugin):
         validate.any(None, validate.get(1))
     )
     _schema_json = validate.Schema(
-        validate.transform(parse_json),
+        validate.parse_json(),
         validate.get("video"),
         validate.get("content_url"),
         validate.url()
