@@ -1,8 +1,15 @@
+"""
+$description Saudi Arabian live TV channels from Rotana Media Group, including Classic, Clip, Comedy, Drama, Kids and LBC.
+$url rotana.net
+$type live
+$region Saudi Arabia
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
