@@ -1,3 +1,11 @@
+"""
+$description Live TV channels and video on-demand service from RTBF, a Belgian public broadcaster.
+$url rtbf.be/auvio
+$url rtbfradioplayer.be
+$type live, vod
+$region Belgium, Europe
+"""
+
 import datetime
 import logging
 import re
@@ -5,8 +13,9 @@ from html import unescape as html_unescape
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import DASHStream, HLSStream, HTTPStream
-from streamlink.utils import parse_json
+from streamlink.stream.dash import DASHStream
+from streamlink.stream.hls import HLSStream
+from streamlink.stream.http import HTTPStream
 
 log = logging.getLogger(__name__)
 
@@ -53,7 +62,7 @@ class RTBF(Plugin):
             validate.all(
                 validate.get(1),
                 validate.transform(html_unescape),
-                validate.transform(parse_json),
+                validate.parse_json(),
                 {
                     'geoLocRestriction': validate.text,
                     validate.optional('isLive'): bool,
