@@ -1,9 +1,14 @@
-"""Plugin for RUV, the Icelandic national television."""
+"""
+$description Live TV channels and video on-demand service from RUV, an Icelandic public, state-owned broadcaster.
+$url ruv.is
+$type live, vod
+$region Iceland
+"""
 
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 # URL to the RUV LIVE API
 RUV_LIVE_API = """http://www.ruv.is/sites/all/themes/at_ruv/scripts/\
