@@ -1,9 +1,15 @@
+"""
+$description Global video hosting platform.
+$url streamable.com
+$type vod
+"""
+
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HTTPStream
-from streamlink.utils import parse_json, update_scheme
+from streamlink.stream.http import HTTPStream
+from streamlink.utils.url import update_scheme
 
 
 @pluginmatcher(re.compile(
@@ -16,7 +22,7 @@ class Streamable(Plugin):
         validate.any(None,
                      validate.all(
                          validate.get(1),
-                         validate.transform(parse_json),
+                         validate.parse_json(),
                          {
                              "files": {validate.text: {"url": validate.url(),
                                                        "width": int,
@@ -30,7 +36,7 @@ class Streamable(Plugin):
         data = self.session.http.get(self.url, schema=self.config_schema)
 
         for info in data["files"].values():
-            stream_url = update_scheme(self.url, info["url"])
+            stream_url = update_scheme("https://", info["url"])
             # pick the smaller of the two dimensions, for landscape v. portrait videos
             res = min(info["width"], info["height"])
             yield "{0}p".format(res), HTTPStream(self.session, stream_url)
