@@ -1,16 +1,26 @@
+"""
+$description French live TV channels from TF1 Group, including LCI and TF1.
+$url tf1.fr
+$url lci.fr
+$type live
+$region France
+"""
+
 import logging
 import re
 
-from streamlink.exceptions import PluginError
-from streamlink.plugin import Plugin
+from streamlink.plugin import Plugin, PluginError, pluginmatcher
 from streamlink.plugin.api import useragents
-from streamlink.stream import DASHStream, HLSStream
+from streamlink.stream.dash import DASHStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
 
+@pluginmatcher(re.compile(
+    r"https?://(?:www\.)?(?:tf1\.fr/([\w-]+)/direct|(lci)\.fr/direct)/?"
+))
 class TF1(Plugin):
-    url_re = re.compile(r"https?://(?:www\.)?(?:tf1\.fr/([\w-]+)/direct|(lci).fr/direct)/?")
     api_url = "https://mediainfo.tf1.fr/mediainfocombo/{}?context=MYTF1&pver=4001000"
 
     def api_call(self, channel, useragent=useragents.CHROME):
@@ -29,12 +39,8 @@ class TF1(Plugin):
             log.debug("Got {format} stream {url}".format(**data['delivery']))
             yield data['delivery']['format'], data['delivery']['url']
 
-    @classmethod
-    def can_handle_url(cls, url):
-        return cls.url_re.match(url) is not None
-
     def _get_streams(self):
-        m = self.url_re.match(self.url)
+        m = self.match
         if m:
             channel = m.group(1) or m.group(2)
             log.debug("Found channel {0}".format(channel))
