@@ -1,9 +1,24 @@
+"""
+$description Turkish live TV channels from Turkuvaz Media Group, including Ahaber, ATV, Minika COCUK and MinikaGO.
+$url atv.com.tr
+$url a2tv.com.tr
+$url ahaber.com.tr
+$url anews.com.tr
+$url aspor.com.tr
+$url atvavrupa.tv
+$url minikacocuk.com.tr
+$url minikago.com.tr
+$url sabah.com.tr
+$type live
+$region various
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import useragents, validate
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
