@@ -1,9 +1,16 @@
+"""
+$description Live TV channels and video on-demand service from CCMA, a Catalan public, state-owned broadcaster.
+$url ccma.cat
+$type live, vod
+$region Spain
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, PluginError, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
