@@ -1,9 +1,15 @@
+"""
+$description Turkish live TV channel owned by Acun Medya Group.
+$url tv8.com.tr
+$type live
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
@@ -14,8 +20,7 @@ log = logging.getLogger(__name__)
 class TV8(Plugin):
     _re_hls = re.compile(r"""file\s*:\s*(["'])(?P<hls_url>https?://.*?\.m3u8.*?)\1""")
 
-    def get_title(self):
-        return 'TV8'
+    title = "TV8"
 
     def _get_streams(self):
         hls_url = self.session.http.get(self.url, schema=validate.Schema(
