@@ -1,9 +1,16 @@
+"""
+$description Live TV channels from TVR, a Romanian public, state-owned broadcaster.
+$url tvrplus.ro
+$type live
+$region Romania
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
