@@ -1,15 +1,14 @@
 """
-Plugin for vidio.com
-- https://www.vidio.com/live/5075-dw-tv-stream
-- https://www.vidio.com/watch/766861-5-rekor-fantastis-zidane-bersama-real-madrid
+$description Indonesian & international live TV channels and video on-demand service. OTT service from Vidio.
+$url vidio.com
+$type live, vod
 """
 import logging
 import re
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import useragents, validate
-from streamlink.stream import HLSStream
-from streamlink.utils import parse_json
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
@@ -23,7 +22,7 @@ class Vidio(Plugin):
 
     csrf_tokens_url = "https://www.vidio.com/csrf_tokens"
     tokens_url = "https://www.vidio.com/live/{id}/tokens"
-    token_schema = validate.Schema(validate.transform(parse_json),
+    token_schema = validate.Schema(validate.parse_json(),
                                    {"token": validate.text},
                                    validate.get("token"))
 
