@@ -1,3 +1,10 @@
+"""
+$description Global live streaming and video hosting social platform.
+$url vimeo.com
+$type live, vod
+$notes Password protected streams are not supported
+"""
+
 import logging
 import re
 from html import unescape as html_unescape
@@ -5,9 +12,10 @@ from urllib.parse import urlparse
 
 from streamlink.plugin import Plugin, PluginArgument, PluginArguments, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import DASHStream, HLSStream, HTTPStream
+from streamlink.stream.dash import DASHStream
 from streamlink.stream.ffmpegmux import MuxedStream
-from streamlink.utils import parse_json
+from streamlink.stream.hls import HLSStream
+from streamlink.stream.http import HTTPStream
 
 log = logging.getLogger(__name__)
 
@@ -24,14 +32,14 @@ class Vimeo(Plugin):
             None,
             validate.Schema(
                 validate.get(1),
-                validate.transform(parse_json),
+                validate.parse_json(),
                 validate.transform(html_unescape),
                 validate.url(),
             ),
         ),
     )
     _config_schema = validate.Schema(
-        validate.transform(parse_json),
+        validate.parse_json(),
         {
             "request": {
                 "files": {
