@@ -1,20 +1,28 @@
+"""
+$description Live and on-demand video service from World Wrestling Entertainment, Inc.
+$url network.wwe.com
+$type live, vod
+$account Required
+"""
+
 import json
 import logging
 import re
 from functools import lru_cache
 from urllib.parse import parse_qsl, urlparse
 
-from streamlink import PluginError
-from streamlink.plugin import Plugin, PluginArgument, PluginArguments
+from streamlink.plugin import Plugin, PluginArgument, PluginArguments, PluginError, pluginmatcher
 from streamlink.plugin.api import useragents
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 from streamlink.utils.times import seconds_to_hhmmss
 
 log = logging.getLogger(__name__)
 
 
+@pluginmatcher(re.compile(
+    r"https?://watch\.wwe\.com/(channel)?"
+))
 class WWENetwork(Plugin):
-    url_re = re.compile(r"https?://watch\.wwe\.com/(channel)?")
     site_config_re = re.compile(r'''">window.__data = (\{.*?\})</script>''')
     stream_url = "https://dce-frontoffice.imggaming.com/api/v2/stream/{id}"
     live_url = "https://dce-frontoffice.imggaming.com/api/v2/event/live"
@@ -49,10 +57,6 @@ class WWENetwork(Plugin):
         self.session.http.headers.update({"User-Agent": useragents.CHROME})
         self.auth_token = None
 
-    @classmethod
-    def can_handle_url(cls, url):
-        return cls.url_re.match(url) is not None
-
     def get_title(self):
         return self.item_config['title']
 
