@@ -1,3 +1,22 @@
+"""
+$description European live TV channels and video on-demand service. OTT service from Zattoo.
+$url zattoo.com
+$url iptv.glattvision.ch
+$url www.saktv.ch
+$url www.vtxtv.ch
+$url mobiltv.quickline.com
+$url www.quantum-tv.com
+$url tvonline.ewe.de
+$url nettv.netcologne.de
+$url tvplus.m-net.de
+$url player.waly.tv
+$url www.1und1.tv
+$url www.netplus.tv
+$url www.bbv-tv.net
+$url www.meinewelt.cc
+$type live, vod
+"""
+
 import logging
 import re
 import uuid
@@ -5,8 +24,8 @@ import uuid
 from streamlink.cache import Cache
 from streamlink.plugin import Plugin, PluginArgument, PluginArguments, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import DASHStream, HLSStream
-from streamlink.utils import parse_json
+from streamlink.stream.dash import DASHStream
+from streamlink.stream.hls import HLSStream
 from streamlink.utils.args import comma_list_filter
 
 log = logging.getLogger(__name__)
@@ -114,7 +133,7 @@ class Zattoo(Plugin):
         log.debug('_hello ...')
         app_token = self.session.http.get(
             f'{self.base_url}/token.json',
-            schema=validate.Schema(validate.transform(parse_json), {
+            schema=validate.Schema(validate.parse_json(), {
                 'success': bool,
                 'session_token': str,
             }, validate.get('session_token'))
@@ -138,7 +157,7 @@ class Zattoo(Plugin):
             headers=self.headers,
             data=params,
             schema=validate.Schema(
-                validate.transform(parse_json),
+                validate.parse_json(),
                 validate.any({'active': bool}, {'success': bool})
             )
         )
@@ -159,7 +178,7 @@ class Zattoo(Plugin):
                 'format': 'json',
             },
             acceptable_status=(200, 400),
-            schema=validate.Schema(validate.transform(parse_json), validate.any(
+            schema=validate.Schema(validate.parse_json(), validate.any(
                 {'active': bool, 'power_guide_hash': str},
                 {'success': bool},
             )),
@@ -212,7 +231,7 @@ class Zattoo(Plugin):
                 headers=self.headers,
                 data=params,
                 acceptable_status=(200, 402, 403, 404),
-                schema=validate.Schema(validate.transform(parse_json), validate.any({
+                schema=validate.Schema(validate.parse_json(), validate.any({
                     'success': validate.transform(bool),
                     'stream': {
                         'watch_urls': [{
@@ -328,7 +347,7 @@ class Zattoo(Plugin):
             log.debug('Session control for {0}'.format(self.domain))
             active = self.session.http.get(
                 f'{self.base_url}/zapi/v3/session',
-                schema=validate.Schema(validate.transform(parse_json),
+                schema=validate.Schema(validate.parse_json(),
                                        {'active': bool}, validate.get('active'))
             )
             if active:
