@@ -1,23 +1,22 @@
 import logging
 import pkgutil
-from collections import OrderedDict
 from functools import lru_cache
 from socket import AF_INET, AF_INET6
-from typing import Dict, Optional, Type
+from typing import Any, Dict, Optional, Tuple, Type
 
 import requests
 import requests.packages.urllib3.util.connection as urllib3_connection
 from requests.packages.urllib3.util.connection import allowed_gai_family
 
 from streamlink import __version__, plugins
-from streamlink.compat import is_win32
 from streamlink.exceptions import NoPluginError, PluginError
 from streamlink.logger import StreamlinkLogger
 from streamlink.options import Options
-from streamlink.plugin import Plugin, api
-from streamlink.plugin.plugin import Matcher, NORMAL_PRIORITY, NO_PRIORITY
-from streamlink.utils import load_module, update_scheme
+from streamlink.plugin.api.http_session import HTTPSession
+from streamlink.plugin.plugin import Matcher, NORMAL_PRIORITY, NO_PRIORITY, Plugin
 from streamlink.utils.l10n import Localization
+from streamlink.utils.module import load_module
+from streamlink.utils.url import update_scheme
 
 # Ensure that the Logger class returned is Streamslink's for using the API (for backwards compatibility)
 logging.setLoggerClass(StreamlinkLogger)
@@ -29,31 +28,41 @@ class PythonDeprecatedWarning(UserWarning):
 
 
 class Streamlink:
-    """A Streamlink session is used to keep track of plugins,
-       options and log settings."""
+    """
+    The Streamlink session is used to load and resolve plugins, and to store options used by plugins and stream implementations.
+    """
 
-    def __init__(self, options=None):
-        self.http = api.HTTPSession()
+    http: HTTPSession
+    """
+    An instance of Streamlink's :class:`requests.Session` subclass.
+    Used for any kind of HTTP request made by plugin and stream implementations.
+    """
+
+    def __init__(
+        self,
+        options: Optional[Dict[str, Any]] = None
+    ):
+        """
+        :param options: Custom options
+        """
+
+        self.http = HTTPSession()
         self.options = Options({
             "interface": None,
             "ipv4": False,
             "ipv6": False,
-            "hds-live-edge": 10.0,
             "hls-live-edge": 3,
             "hls-segment-ignore-names": [],
+            "hls-segment-stream-data": False,
             "hls-playlist-reload-attempts": 3,
             "hls-playlist-reload-time": "default",
             "hls-start-offset": 0,
             "hls-duration": None,
             "ringbuffer-size": 1024 * 1024 * 16,  # 16 MB
-            "rtmp-rtmpdump": is_win32 and "rtmpdump.exe" or "rtmpdump",
-            "rtmp-proxy": None,
             "stream-segment-attempts": 3,
             "stream-segment-threads": 1,
             "stream-segment-timeout": 10.0,
             "stream-timeout": 60.0,
-            "subprocess-errorlog": False,
-            "subprocess-errorlog-path": None,
             "ffmpeg-ffmpeg": None,
             "ffmpeg-fout": None,
             "ffmpeg-video-transcode": None,
@@ -66,12 +75,12 @@ class Streamlink:
         })
         if options:
             self.options.update(options)
-        self.plugins: Dict[str, Type[Plugin]] = OrderedDict({})
+        self.plugins: Dict[str, Type[Plugin]] = {}
         self.load_builtin_plugins()
 
-    def set_option(self, key, value):
-        """Sets general options used by plugins and streams originating
-        from this session object.
+    def set_option(self, key: str, value: Any):
+        """
+        Sets general options used by plugins and streams originating from this session object.
 
         :param key: key of the option
         :param value: value to set the option to
@@ -86,9 +95,6 @@ class Streamlink:
                                  This option overrides ipv6, default: ``False``
         ipv6                     (bool) Resolve address names to IPv6 only.
                                  This option overrides ipv4, default: ``False``
-        hds-live-edge            (float) Specify the time live HDS
-                                 streams will start from the edge of
-                                 stream, default: ``10.0``
 
         hls-live-edge            (int) How many segments from the end
                                  to start live streams on, default: ``3``
@@ -100,28 +106,28 @@ class Streamlink:
         hls-segment-stream-data  (bool) Stream HLS segment downloads,
                                  default: ``False``
 
-        http-proxy               (str) Specify a HTTP proxy to use for
+        http-proxy               (str) Specify an HTTP proxy to use for
                                  all HTTP requests
 
-        https-proxy              (str) Specify a HTTPS proxy to use for
+        https-proxy              (str) Specify an HTTPS proxy to use for
                                  all HTTPS requests
 
-        http-cookies             (dict or str) A dict or a semi-colon (;)
+        http-cookies             (dict or str) A dict or a semicolon ``;``
                                  delimited str of cookies to add to each
                                  HTTP request, e.g. ``foo=bar;baz=qux``
 
-        http-headers             (dict or str) A dict or semi-colon (;)
+        http-headers             (dict or str) A dict or semicolon ``;``
                                  delimited str of headers to add to each
                                  HTTP request, e.g. ``foo=bar;baz=qux``
 
-        http-query-params        (dict or str) A dict or a ampersand (&)
+        http-query-params        (dict or str) A dict or an ampersand ``&``
                                  delimited string of query parameters to
                                  add to each HTTP request,
                                  e.g. ``foo=bar&baz=qux``
 
         http-trust-env           (bool) Trust HTTP settings set in the
                                  environment, such as environment
-                                 variables (HTTP_PROXY, etc) and
+                                 variables (HTTP_PROXY, etc.) and
                                  ~/.netrc authentication
 
         http-ssl-verify          (bool) Verify SSL certificates,
@@ -135,23 +141,10 @@ class Streamlink:
                                  requests except the ones covered by
                                  other options, default: ``20.0``
 
-        subprocess-errorlog      (bool) Log errors from subprocesses to
-                                 a file located in the temp directory
-
-        subprocess-errorlog-path (str) Log errors from subprocesses to
-                                 a specific file
-
         ringbuffer-size          (int) The size of the internal ring
                                  buffer used by most stream types,
                                  default: ``16777216`` (16MB)
 
-        rtmp-proxy               (str) Specify a proxy (SOCKS) that RTMP
-                                 streams will use
-
-        rtmp-rtmpdump            (str) Specify the location of the
-                                 rtmpdump executable used by RTMP streams,
-                                 e.g. ``/usr/local/bin/rtmpdump``
-
         ffmpeg-ffmpeg            (str) Specify the location of the
                                  ffmpeg executable use by Muxing streams
                                  e.g. ``/usr/local/bin/ffmpeg``
@@ -177,7 +170,7 @@ class Streamlink:
         ffmpeg-copyts            (bool) When used with ffmpeg, do not shift input timestamps.
 
         ffmpeg-start-at-zero     (bool) When used with ffmpeg and copyts,
-                                 shift input timestamps so they start at zero
+                                 shift input timestamps, so they start at zero
                                  default: ``False``
 
         mux-subtitles            (bool) Mux available subtitles into the
@@ -196,7 +189,7 @@ class Streamlink:
                                  stream, default: ``60.0``.
 
         locale                   (str) Locale setting, in the RFC 1766 format
-                                 eg. en_US or es_ES
+                                 e.g. en_US or es_ES
                                  default: ``system locale``.
 
         user-input-requester     (UserInputRequester) instance of UserInputRequester
@@ -204,7 +197,6 @@ class Streamlink:
                                  set before the plugins are loaded.
                                  default: ``UserInputRequester``.
         ======================== =========================================
-
         """
 
         if key == "interface":
@@ -229,13 +221,12 @@ class Streamlink:
             else:
                 urllib3_connection.allowed_gai_family = allowed_gai_family
 
-        elif key == "http-proxy":
-            self.http.proxies["http"] = update_scheme("http://", value)
-            if "https" not in self.http.proxies:
-                self.http.proxies["https"] = update_scheme("http://", value)
+        elif key in ("http-proxy", "https-proxy"):
+            self.http.proxies["http"] = update_scheme("https://", value, force=False)
+            self.http.proxies["https"] = self.http.proxies["http"]
+            if key == "https-proxy":
+                log.info("The https-proxy option has been deprecated in favour of a single http-proxy option")
 
-        elif key == "https-proxy":
-            self.http.proxies["https"] = update_scheme("https://", value)
         elif key == "http-cookies":
             if isinstance(value, dict):
                 self.http.cookies.update(value)
@@ -269,24 +260,25 @@ class Streamlink:
         elif key == "http-timeout":
             self.http.timeout = value
 
-        # deprecated: {dash,hds,hls}-segment-attempts
-        elif key in ("dash-segment-attempts", "hds-segment-attempts", "hls-segment-attempts"):
+        # deprecated: {dash,hls}-segment-attempts
+        elif key in ("dash-segment-attempts", "hls-segment-attempts"):
             self.options.set("stream-segment-attempts", int(value))
-        # deprecated: {dash,hds,hls}-segment-threads
-        elif key in ("dash-segment-threads", "hds-segment-threads", "hls-segment-threads"):
+        # deprecated: {dash,hls}-segment-threads
+        elif key in ("dash-segment-threads", "hls-segment-threads"):
             self.options.set("stream-segment-threads", int(value))
-        # deprecated: {dash,hds,hls}-segment-timeout
-        elif key in ("dash-segment-timeout", "hds-segment-timeout", "hls-segment-timeout"):
+        # deprecated: {dash,hls}-segment-timeout
+        elif key in ("dash-segment-timeout", "hls-segment-timeout"):
             self.options.set("stream-segment-timeout", float(value))
-        # deprecated: {hds,hls,rtmp,dash,http-stream}-timeout
-        elif key in ("dash-timeout", "hds-timeout", "hls-timeout", "http-stream-timeout", "rtmp-timeout"):
+        # deprecated: {hls,dash,http-stream}-timeout
+        elif key in ("dash-timeout", "hls-timeout", "http-stream-timeout"):
             self.options.set("stream-timeout", float(value))
 
         else:
             self.options.set(key, value)
 
-    def get_option(self, key):
-        """Returns current value of specified option.
+    def get_option(self, key: str):
+        """
+        Returns the current value of the specified option.
 
         :param key: key of the option
 
@@ -313,26 +305,25 @@ class Streamlink:
         else:
             return self.options.get(key)
 
-    def set_plugin_option(self, plugin, key, value):
-        """Sets plugin specific options used by plugins originating
-        from this session object.
+    def set_plugin_option(self, plugin: str, key: str, value: Any):
+        """
+        Sets plugin specific options used by plugins originating from this session object.
 
         :param plugin: name of the plugin
         :param key: key of the option
         :param value: value to set the option to
-
         """
 
         if plugin in self.plugins:
             plugin = self.plugins[plugin]
             plugin.set_option(key, value)
 
-    def get_plugin_option(self, plugin, key):
-        """Returns current value of plugin specific option.
+    def get_plugin_option(self, plugin: str, key: str):
+        """
+        Returns the current value of the plugin specific option.
 
         :param plugin: name of the plugin
         :param key: key of the option
-
         """
 
         if plugin in self.plugins:
@@ -340,19 +331,24 @@ class Streamlink:
             return plugin.get_option(key)
 
     @lru_cache(maxsize=128)
-    def resolve_url(self, url: str, follow_redirect: bool = True) -> Plugin:
-        """Attempts to find a plugin that can use this URL.
+    def resolve_url(
+        self,
+        url: str,
+        follow_redirect: bool = True
+    ) -> Tuple[Type[Plugin], str]:
+        """
+        Attempts to find a plugin that can use this URL.
 
-        The default protocol (http) will be prefixed to the URL if
-        not specified.
+        The default protocol (https) will be prefixed to the URL if not specified.
 
-        Raises :exc:`NoPluginError` on failure.
+        Return values of this method are cached via :meth:`functools.lru_cache`.
 
         :param url: a URL to match against loaded plugins
         :param follow_redirect: follow redirects
-
+        :raises NoPluginError: on plugin resolve failure
         """
-        url = update_scheme("http://", url)
+
+        url = update_scheme("https://", url, force=False)
 
         matcher: Matcher
         candidate: Optional[Type[Plugin]] = None
@@ -372,11 +368,12 @@ class Streamlink:
                     priority = prio
 
         if candidate:
-            return candidate(url)
+            return candidate, url
 
         if follow_redirect:
             # Attempt to handle a redirect URL
             try:
+                # noinspection PyArgumentList
                 res = self.http.head(url, allow_redirects=True, acceptable_status=[501])
 
                 # Fall back to GET request if server doesn't handle HEAD.
@@ -390,28 +387,31 @@ class Streamlink:
 
         raise NoPluginError
 
-    def resolve_url_no_redirect(self, url):
-        """Attempts to find a plugin that can use this URL.
+    def resolve_url_no_redirect(self, url: str) -> Tuple[Type[Plugin], str]:
+        """
+        Attempts to find a plugin that can use this URL.
 
-        The default protocol (http) will be prefixed to the URL if
-        not specified.
-
-        Raises :exc:`NoPluginError` on failure.
+        The default protocol (https) will be prefixed to the URL if not specified.
 
         :param url: a URL to match against loaded plugins
-
+        :raises NoPluginError: on plugin resolve failure
         """
+
         return self.resolve_url(url, follow_redirect=False)
 
-    def streams(self, url, **params):
-        """Attempts to find a plugin and extract streams from the *url*.
+    def streams(self, url: str, **params):
+        """
+        Attempts to find a plugin and extracts streams from the *url* if a plugin was found.
 
-        *params* are passed to :func:`Plugin.streams`.
-
-        Raises :exc:`NoPluginError` if no plugin is found.
+        :param url: a URL to match against loaded plugins
+        :param params: Additional keyword arguments passed to :meth:`streamlink.plugin.Plugin.streams`
+        :raises NoPluginError: on plugin resolve failure
+        :return: A :class:`dict` of stream names and :class:`streamlink.stream.Stream` instances
         """
 
-        plugin = self.resolve_url(url)
+        pluginclass, resolved_url = self.resolve_url(url)
+        plugin = pluginclass(resolved_url)
+
         return plugin.streams(**params)
 
     def get_plugins(self):
@@ -423,11 +423,13 @@ class Streamlink:
         self.load_plugins(plugins.__path__[0])
 
     def load_plugins(self, path: str) -> bool:
-        """Attempt to load plugins from the path specified.
+        """
+        Attempt to load plugins from the path specified.
 
         :param path: full path to a directory where to look for plugins
         :return: success
         """
+
         success = False
         user_input_requester = self.get_option("user-input-requester")
         for loader, name, ispkg in pkgutil.iter_modules([path]):
