@@ -1,10 +1,9 @@
 import logging
 import re
 import struct
-from collections import OrderedDict, defaultdict
 from concurrent.futures import Future
 from threading import Event
-from typing import List, NamedTuple, Optional, Union
+from typing import Any, Dict, List, NamedTuple, Optional, Tuple, Union
 from urllib.parse import urlparse
 
 # noinspection PyPackageRequirements
@@ -12,15 +11,15 @@ from Crypto.Cipher import AES
 # noinspection PyPackageRequirements
 from Crypto.Util.Padding import unpad
 from requests import Response
-from requests.exceptions import ChunkedEncodingError, ConnectionError, ContentDecodingError
+from requests.exceptions import ChunkedEncodingError, ConnectionError, ContentDecodingError, StreamConsumedError
 
 from streamlink.exceptions import StreamError
-from streamlink.stream import hls_playlist
 from streamlink.stream.ffmpegmux import FFMPEGMuxer, MuxedStream
-from streamlink.stream.hls_playlist import Key, M3U8, Map, Segment
+from streamlink.stream.hls_playlist import ByteRange, Key, M3U8, Map, Segment, load as load_hls_playlist
 from streamlink.stream.http import HTTPStream
-from streamlink.stream.segmented import (SegmentedStreamReader, SegmentedStreamWorker, SegmentedStreamWriter)
-from streamlink.utils import LRUCache, LazyFormatter
+from streamlink.stream.segmented import SegmentedStreamReader, SegmentedStreamWorker, SegmentedStreamWriter
+from streamlink.utils.cache import LRUCache
+from streamlink.utils.formatter import Formatter
 
 log = logging.getLogger(__name__)
 
@@ -30,16 +29,50 @@ class Sequence(NamedTuple):
     segment: Segment
 
 
+class ByteRangeOffset:
+    sequence: Sequence.num = None
+    offset: int = None
+
+    @staticmethod
+    def _calc_end(start: int, size: ByteRange.range):
+        return start + max(size - 1, 0)
+
+    def cached(self, sequence: Sequence.num, byterange: ByteRange) -> Tuple[int, int]:
+        if byterange.offset is not None:
+            bytes_start = byterange.offset
+        elif self.offset is not None and self.sequence == sequence - 1:
+            bytes_start = self.offset
+        else:
+            raise StreamError("Missing BYTERANGE offset")
+
+        bytes_end = self._calc_end(bytes_start, byterange.range)
+
+        self.sequence = sequence
+        self.offset = bytes_end + 1
+
+        return bytes_start, bytes_end
+
+    def uncached(self, byterange: ByteRange) -> Tuple[int, int]:
+        bytes_start = byterange.offset
+        if bytes_start is None:
+            raise StreamError("Missing BYTERANGE offset")
+
+        return bytes_start, self._calc_end(bytes_start, byterange.range)
+
+
 class HLSStreamWriter(SegmentedStreamWriter):
+    WRITE_CHUNK_SIZE = 8192
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         options = self.session.options
 
-        self.byterange_offsets = defaultdict(int)
+        self.byterange: ByteRangeOffset = ByteRangeOffset()
         self.map_cache: LRUCache[Sequence.segment.map.uri, Future] = LRUCache(self.threads)
         self.key_data = None
         self.key_uri = None
         self.key_uri_override = options.get("hls-segment-key-uri")
+        self.stream_data = options.get("hls-segment-stream-data")
 
         self.ignore_names = False
         ignore_names = {*options.get("hls-segment-ignore-names")}
@@ -53,21 +86,21 @@ class HLSStreamWriter(SegmentedStreamWriter):
 
     def create_decryptor(self, key: Key, num: int) -> AES:
         if key.method != "AES-128":
-            raise StreamError("Unable to decrypt cipher {0}", key.method)
+            raise StreamError(f"Unable to decrypt cipher {key.method}")
 
         if not self.key_uri_override and not key.uri:
             raise StreamError("Missing URI to decryption key")
 
         if self.key_uri_override:
             p = urlparse(key.uri)
-            key_uri = LazyFormatter.format(
-                self.key_uri_override,
-                url=key.uri,
-                scheme=p.scheme,
-                netloc=p.netloc,
-                path=p.path,
-                query=p.query,
-            )
+            formatter = Formatter({
+                "url": lambda: key.uri,
+                "scheme": lambda: p.scheme,
+                "netloc": lambda: p.netloc,
+                "path": lambda: p.path,
+                "query": lambda: p.query,
+            })
+            key_uri = formatter.format(self.key_uri_override)
         else:
             key_uri = key.uri
 
@@ -86,19 +119,16 @@ class HLSStreamWriter(SegmentedStreamWriter):
 
         return AES.new(self.key_data, AES.MODE_CBC, iv)
 
-    def create_request_params(self, segment: Union[Segment, Map]):
+    def create_request_params(self, num: Sequence.num, segment: Union[Segment, Map], is_map: bool):
         request_params = dict(self.reader.request_params)
         headers = request_params.pop("headers", {})
 
         if segment.byterange:
-            bytes_start = self.byterange_offsets[segment.uri]
-            if segment.byterange.offset is not None:
-                bytes_start = segment.byterange.offset
-
-            bytes_len = max(segment.byterange.range - 1, 0)
-            bytes_end = bytes_start + bytes_len
+            if is_map:
+                bytes_start, bytes_end = self.byterange.uncached(segment.byterange)
+            else:
+                bytes_start, bytes_end = self.byterange.cached(num, segment.byterange)
             headers["Range"] = f"bytes={bytes_start}-{bytes_end}"
-            self.byterange_offsets[segment.uri] = bytes_end + 1
 
         request_params["headers"] = headers
 
@@ -127,28 +157,33 @@ class HLSStreamWriter(SegmentedStreamWriter):
 
     def fetch(self, sequence: Sequence) -> Optional[Response]:
         try:
-            return self._fetch(sequence.segment, not sequence.segment.key)
-        except StreamError as err:  # pragma: no cover
+            return self._fetch(
+                sequence.segment.uri,
+                stream=self.stream_data and not sequence.segment.key,
+                **self.create_request_params(sequence.num, sequence.segment, False)
+            )
+        except StreamError as err:
             log.error(f"Failed to fetch segment {sequence.num}: {err}")
 
     def fetch_map(self, sequence: Sequence) -> Optional[Response]:
         try:
-            return self._fetch(sequence.segment.map, False)
-        except StreamError as err:  # pragma: no cover
+            return self._fetch(
+                sequence.segment.map.uri,
+                stream=False,
+                **self.create_request_params(sequence.num, sequence.segment.map, True)
+            )
+        except StreamError as err:
             log.error(f"Failed to fetch map for segment {sequence.num}: {err}")
 
-    def _fetch(self, segment: Union[Segment, Map], stream: bool) -> Optional[Response]:
+    def _fetch(self, url: str, **request_params) -> Optional[Response]:
         if self.closed or not self.retries:  # pragma: no cover
             return
 
-        request_params = self.create_request_params(segment)
-
         return self.session.http.get(
-            segment.uri,
-            stream=stream,
+            url,
             timeout=self.timeout,
-            exception=StreamError,
             retries=self.retries,
+            exception=StreamError,
             **request_params
         )
 
@@ -164,11 +199,21 @@ class HLSStreamWriter(SegmentedStreamWriter):
                 if not self.reader.filter_event.is_set():
                     log.info("Resuming stream output")
                     self.reader.filter_event.set()
+        else:
+            self._write_discard(sequence, *args, **kwargs)
+            # block reader thread if filtering out segments
+            if self.reader.filter_event.is_set():
+                log.info("Filtering out segments and pausing stream output")
+                self.reader.filter_event.clear()
 
-        # block reader thread if filtering out segments
-        elif self.reader.filter_event.is_set():
-            log.info("Filtering out segments and pausing stream output")
-            self.reader.filter_event.clear()
+    def _write_discard(self, sequence: Sequence, res: Response, is_map: bool):
+        # The full response needs to actually be read from the socket
+        # even if there isn't any intention of using the payload
+        try:
+            for _ in res.iter_content(self.WRITE_CHUNK_SIZE):
+                pass
+        except (ChunkedEncodingError, ContentDecodingError, ConnectionError, StreamConsumedError):
+            pass
 
     def _write(self, sequence: Sequence, res: Response, is_map: bool):
         if sequence.segment.key and sequence.segment.key.method != "NONE":
@@ -192,7 +237,7 @@ class HLSStreamWriter(SegmentedStreamWriter):
             self.reader.buffer.write(chunk)
         else:
             try:
-                for chunk in res.iter_content(8192):
+                for chunk in res.iter_content(self.WRITE_CHUNK_SIZE):
                     self.reader.buffer.write(chunk)
             except (ChunkedEncodingError, ContentDecodingError, ConnectionError) as err:
                 log.error(f"Download of segment {sequence.num} failed ({err})")
@@ -228,7 +273,7 @@ class HLSStreamWorker(SegmentedStreamWorker):
             self.playlist_reload_time_override = 0
 
     def _reload_playlist(self, text, url):
-        return hls_playlist.load(text, url)
+        return load_hls_playlist(text, url)
 
     def reload_playlist(self):
         if self.closed:  # pragma: no cover
@@ -403,9 +448,32 @@ class HLSStreamReader(SegmentedStreamReader):
 
 
 class MuxedHLSStream(MuxedStream):
+    """
+    Muxes multiple HLS video and audio streams into one output stream.
+    """
+
     __shortname__ = "hls-multi"
 
-    def __init__(self, session, video, audio, url_master=None, force_restart=False, ffmpeg_options=None, **args):
+    def __init__(
+        self,
+        session,
+        video: str,
+        audio: Union[str, List[str]],
+        url_master: Optional[str] = None,
+        force_restart: bool = False,
+        ffmpeg_options: Optional[Dict[str, Any]] = None,
+        **args
+    ):
+        """
+        :param streamlink.Streamlink session: Streamlink session instance
+        :param video: Video stream URL
+        :param audio: Audio stream URL or list of URLs
+        :param url_master: The URL of the HLS playlist's master/variant playlist
+        :param force_restart: Start from the beginning after reaching the playlist's end
+        :param ffmpeg_options: Additional keyword arguments passed to :class:`ffmpegmux.FFMPEGMuxer`
+        :param args: Additional keyword arguments passed to :class:`HLSStream`
+        """
+
         tracks = [video]
         maps = ["0:v?", "0:a?"]
         if audio:
@@ -426,20 +494,33 @@ class MuxedHLSStream(MuxedStream):
 
 
 class HLSStream(HTTPStream):
-    """Implementation of the Apple HTTP Live Streaming protocol
-
-    *Attributes:*
-
-    - :attr:`url` The URL to the HLS playlist.
-    - :attr:`args` A :class:`dict` containing keyword arguments passed
-      to :meth:`requests.request`, such as headers and cookies.
-
+    """
+    Implementation of the Apple HTTP Live Streaming protocol.
     """
 
     __shortname__ = "hls"
     __reader__ = HLSStreamReader
 
-    def __init__(self, session_, url, url_master=None, force_restart=False, start_offset=0, duration=None, **args):
+    def __init__(
+        self,
+        session_,
+        url: str,
+        url_master: Optional[str] = None,
+        force_restart: bool = False,
+        start_offset: float = 0,
+        duration: Optional[float] = None,
+        **args
+    ):
+        """
+        :param streamlink.Streamlink session_: Streamlink session instance
+        :param url: The URL of the HLS playlist
+        :param url_master: The URL of the HLS playlist's master/variant playlist
+        :param force_restart: Start from the beginning after reaching the playlist's end
+        :param start_offset: Number of seconds to be skipped from the beginning
+        :param duration: Number of seconds until ending the stream
+        :param args: Additional keyword arguments passed to :meth:`requests.Session.request`
+        """
+
         super().__init__(session_, url, **args)
         self.url_master = url_master
         self.force_restart = force_restart
@@ -472,25 +553,38 @@ class HLSStream(HTTPStream):
 
     @classmethod
     def _get_variant_playlist(cls, res):
-        return hls_playlist.load(res.text, base_uri=res.url)
+        return load_hls_playlist(res.text, base_uri=res.url)
 
     @classmethod
-    def parse_variant_playlist(cls, session_, url, name_key="name",
-                               name_prefix="", check_streams=False,
-                               force_restart=False, name_fmt=None,
-                               start_offset=0, duration=None,
-                               **request_params):
-        """Attempts to parse a variant playlist and return its streams.
-
-        :param url: The URL of the variant playlist.
-        :param name_key: Prefer to use this key as stream name, valid keys are:
-                         name, pixels, bitrate.
-        :param name_prefix: Add this prefix to the stream names.
-        :param check_streams: Only allow streams that are accessible.
-        :param force_restart: Start at the first segment even for a live stream
-        :param name_fmt: A format string for the name, allowed format keys are
-                         name, pixels, bitrate.
+    def parse_variant_playlist(
+        cls,
+        session_,
+        url: str,
+        name_key: str = "name",
+        name_prefix: str = "",
+        check_streams: bool = False,
+        force_restart: bool = False,
+        name_fmt: Optional[str] = None,
+        start_offset: float = 0,
+        duration: Optional[float] = None,
+        **request_params
+    ) -> Dict[str, Union["HLSStream", "MuxedHLSStream"]]:
         """
+        Parse a variant playlist and return its streams.
+
+        :param streamlink.Streamlink session_: Streamlink session instance
+        :param url: The URL of the variant playlist
+        :param name_key: Prefer to use this key as stream name, valid keys are: name, pixels, bitrate
+        :param name_prefix: Add this prefix to the stream names
+        :param check_streams: Only allow streams that are accessible
+        :param force_restart: Start at the first segment even for a live stream
+        :param name_fmt: A format string for the name, allowed format keys are: name, pixels, bitrate
+        :param start_offset: Number of seconds to be skipped from the beginning
+        :param duration: Number of second until ending the stream
+        :param request_params: Additional keyword arguments passed to :class:`HLSStream`, :class:`MuxedHLSStream`,
+                               or :py:meth:`requests.Session.request`
+        """
+
         locale = session_.localization
         audio_select = session_.options.get("hls-audio-select") or []
 
@@ -501,7 +595,7 @@ class HLSStream(HTTPStream):
         except ValueError as err:
             raise OSError("Failed to parse playlist: {0}".format(err))
 
-        streams = OrderedDict()
+        streams = {}
         for playlist in filter(lambda p: not p.is_iframe, parser.playlists):
             names = dict(name=None, pixels=None, bitrate=None)
             audio_streams = []
